ReliefWeb class

Constructors

ReliefWeb()
Initialize the connection

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Close the connection
getCountries({int limit = 10, int offset = 0}) → Future<List>
List countries covered by ReliefWeb.
getCountryById({required String countryId}) → Future<List>
Get a specific country by id
getDisasterById({required String disasterId}) → Future<List>
Get a specific disaster by id
getDisasters({int limit = 10, int offset = 0}) → Future<List>
List disasters covered by ReliefWeb
getJobById({required String jobId}) → Future<List>
Get a specific report by reportId
getJobs({int limit = 10, int offset = 0}) → Future<List>
List humanitarian job offers
getReportById({required String reportId}) → Future<List>
Get a specific report by reportId
getReports({int limit = 10, int offset = 0}) → Future<List>
Get Reports, Maps, Infographics
getSourceById({required String sourceId}) → Future<List>
Get a specific source by id
getSources({int limit = 10, int offset = 0}) → Future<List>
List organizations providing content to ReliefWeb
getTraining({int limit = 10, int offset = 0}) → Future<List>
List humanitarian learning opportunities
getTrainingById({required String trainingId}) → Future<List>
Get a specific learning opportunity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited